package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.RmsSupplier;
import com.steerinfo.dil.service.impl.RmsSupplierServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.text.ParseException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJieHuan
 * @GreateTime:2021/11/09 17:24
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/rmssupplier")
public class RmsSupplierController extends BaseRESTfulController {

    @Autowired
    RmsSupplierServiceImpl rmsSupplierService;
    @Autowired
    ColumnDataUtil columnDataUtil;

    @Autowired
    ESFeign esFeign;

    /**
     * 展示供应商信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="展示供应商信息", notes="分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "343", required = false, dataType = "BigDecimal"),
    })
    @PostMapping(value = "/getSupplierList")
    public RESTfulResult getSupplierList(@RequestBody(required = false) Map<String,Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize,
                                         String con){

       if (con!=null && !con.equals("undefined")){
           mapValue.put("con","%"+con+"%");
       }
        List<Map<String,Object>>  listTotal = rmsSupplierService.getSupplierList(mapValue);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = rmsSupplierService.getSupplierList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, listTotal, columnList);
        return success(data);
    }

    /**
     * 添加供应商
     */
    @ApiOperation(value="创建", notes="根据RmsSupplier对象创建")
    @ApiImplicitParam(name = "rmsSupplier", value = "详细实体rmsSupplier", required = true, dataType = "RmsSupplier")
    //@RequiresPermissions("rmssupplier:create")
    @PostMapping(value = "/insertSupplier")
    public RESTfulResult insertSupplier(@RequestBody(required = false) Map<String,Object> mapValue) throws ParseException {
        int result= rmsSupplierService.insertSupplier(mapValue);
        if (result <= 0){
            return failed();
        }
        return success(result);
    }

    /**
     * 通过id值来更新信息
     */
    @ApiOperation(value="更新详细信息", notes="根据url的id来指定更新对象，并根据传过来的rmsSupplier信息来更新详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "rmsSupplier", value = "详细实体rmsSupplier", required = true, dataType = "RmsSupplier")
    })
    //@RequiresPermissions("rmssupplier:update")
    @PostMapping(value = "/updateSupplier", produces  = "application/json;charset=UTF-8")
    public RESTfulResult updateSupplier(@RequestBody RmsSupplier rmsSupplier){
        int result= rmsSupplierService.updateSupplier(rmsSupplier);
        return success(result);
    }

    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    //@RequiresPermissions("rmssupplier:delete")
    @PostMapping(value = "/deleteSupplier/{id}")//BigDecimal
    public RESTfulResult deleteSupplier(@PathVariable("id") BigDecimal id){

        return success(rmsSupplierService.deleteSupplier(id));
    }

    /**根据id值详细获取供应商信息
     *
     */
    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getSupplierById/{id}")
    public RESTfulResult getSupplierById(@PathVariable("id") BigDecimal id){
        List<Map<String, Object>> list= rmsSupplierService.getSupplierById(id);
        return success(list);
    }
}
